@@ -6,22 +6,6 @@
 
  This file was written by Asim S. Siddiqui
 
- The WORK was developed by:
-        Asim S. Siddiqui and Geoffrey J. Barton
-        Laboratory of Molecular Biophysics
-        University of Oxford
-        Rex Richards Building
-        South Parks Road
-        Oxford OX1 3QU U.K.
-        Tel:  (+44) 865-275379
-        FAX:  (+44) 865-510454
-        INTERNET: as@bioch.ox.ac.uk
-        JANET:    as@uk.ac.ox.bioch
-
- The WORK is Copyright (1995) University of Oxford
-        Administrative Offices
-        Wellington Square
-        Oxford OX1 2JD U.K.
 
  All use of the WORK must cite:
  Siddiqui, A. S. and Barton, G. J., "Continuous and Discontinuous Domains: An
