@@ -6,31 +6,17 @@
 
  This routine was developed by Robert B. Russell
 
- The WORK was developed by:
-        Asim S. Siddiqui and Geoffrey J. Barton
-        Laboratory of Molecular Biophysics
-        University of Oxford
-        Rex Richards Building
-        South Parks Road
-        Oxford OX1 3QU U.K.
-        Tel:  (+44) 865-275379
-        FAX:  (+44) 865-510454
-        INTERNET: as@bioch.ox.ac.uk
-        JANET:    as@uk.ac.ox.bioch
 
- The WORK is Copyright (1995) University of Oxford
-        Administrative Offices
-        Wellington Square
-        Oxford OX1 2JD U.K.
 
  All use of the WORK must cite:
  Siddiqui, A. S. and Barton, G. J., "Continuous and Discontinuous Domains: An
  Algorithm for the Automatic Generation of Reliable Protein Domain Definitions" 
  PROTEIN SCIENCE, 4:872-884 (1995).
 *****************************************************************************/
+/* $Id: rmsp.c,v 1.4 2004/09/10 14:39:17 geoff Exp $ */
 
 #include <stdio.h>
-#include <malloc.h>
+
 
 /* This routine removes spaces from a string and returns the result. */
 
